@@ -230,7 +230,7 @@ $_gmsg['l_docroot'] = 'Document Root';
 $_gmsg['l_domain'] = 'Domain Name';
 $_gmsg['l_domains'] = 'Domains';
 $_gmsg['l_dynreqpersec'] = 'Dynamic Requests/second';
-$_gmsg['l_enablebrcompress'] = 'Enable Brotli Compression';
+$_gmsg['l_brcompresslevel'] = 'Brotli Compression Level (Dynamic Content)';
 $_gmsg['l_enablecache'] = 'Enable Cache';
 $_gmsg['l_enablecensorship'] = 'Enable Request Filtering';
 $_gmsg['l_enablechroot'] = 'Enable chroot';
@@ -238,7 +238,7 @@ $_gmsg['l_enablecompress'] = 'Enable Compression';
 $_gmsg['l_enablecoredump'] = 'Enable Core Dump';
 $_gmsg['l_enabled'] = 'Enabled';
 $_gmsg['l_enabledhe'] = 'Enable DH Key Exchange';
-$_gmsg['l_enabledyngzipcompress'] = 'Enable Dynamic Compression';
+$_gmsg['l_enabledyngzipcompress'] = 'Enable GZIP Dynamic Compression';
 $_gmsg['l_enableecdhe'] = 'Enable ECDH Key Exchange';
 $_gmsg['l_enablequic'] = 'Enable QUIC';
 $_gmsg['l_enableexpires'] = 'Enable Expires';
@@ -296,10 +296,10 @@ $_gmsg['l_groupdblocation'] = 'Group DB Location';
 $_gmsg['l_groupdbmaxcachesize'] = 'Group DB Max Cache Size';
 $_gmsg['l_groupname'] = 'Group Name';
 $_gmsg['l_groups'] = 'Groups';
-$_gmsg['l_gzip'] = 'GZIP Compression';
+$_gmsg['l_gzipbr'] = 'GZIP/Brotli Compression';
 $_gmsg['l_gzipautoupdatestatic'] = 'Auto Update Static File';
-$_gmsg['l_gzipcachedir'] = 'Static GZIP Cache Directory';
-$_gmsg['l_gzipcompresslevel'] = 'Compression Level (Dynamic Content)';
+$_gmsg['l_gzipcachedir'] = 'Static Cache Directory';
+$_gmsg['l_gzipcompresslevel'] = 'GZIP Compression Level (Dynamic Content)';
 $_gmsg['l_gzipmaxfilesize'] = 'Max Static File Size (bytes)';
 $_gmsg['l_gzipminfilesize'] = 'Min Static File Size (bytes)';
 $_gmsg['l_handlername'] = 'Handler Name';
@@ -481,7 +481,8 @@ $_gmsg['l_sslStrongDhKey'] = 'SSL Strong DH Key';
 $_gmsg['l_sslprotocol'] = 'SSL Protocol';
 $_gmsg['l_startupfile'] = 'Startup File';
 $_gmsg['l_statDir'] = 'Statistics Output Directory';
-$_gmsg['l_staticcompresslevel'] = 'Compression Level (Static File)';
+$_gmsg['l_gzipstaticcompresslevel'] = 'GZIP Compression Level (Static File)';
+$_gmsg['l_brstaticcompresslevel'] = 'Brotli Compression Level (Static File)';
 $_gmsg['l_staticreqpersec'] = 'Static Requests/second';
 $_gmsg['l_statuscode'] = 'Status Code';
 $_gmsg['l_storagepath'] = 'Storage Path';
